@@ -7,7 +7,7 @@
 #ifndef GASCALCULATOR_H
 #define GASCALCULATOR_H
 
-#include <QDebug>
+#include "kalzium_debug.h"
 
 #include <KUnitConversion/Converter>
 #include <KUnitConversion/UnitCategory>
@@ -61,7 +61,7 @@ public:
     explicit gasCalculator(QWidget * parent = nullptr);
     ~gasCalculator();
 
-public slots:
+public Q_SLOTS:
     /// Calculates the Pressure and updates the UI
     void calculatePressure();
 
