@@ -35,7 +35,7 @@ Q_SIGNALS:
     void elementMatched(int element);
     void resetElementMatch();
 
-public slots:
+public Q_SLOTS:
     void updateContent();
 
     void setDockArea(Qt::DockWidgetArea newDockArea);
@@ -68,7 +68,7 @@ class LegendItem : public QLabel
     Q_OBJECT
 
 public:
-    LegendItem(const QPair<QString, QColor>& pair, QWidget * parent = nullptr);
+    LegendItem(const QPair<QString, QColor>& pair, LegendWidget * parent = nullptr);
     ~LegendItem() {}
 
 Q_SIGNALS:
